@@ -384,6 +384,14 @@ class Scheduler:
             if task.name and self.tasks.has_key(task.name):
                 del self.tasks[task.name]
 
+    def rename(self, taskname, newname):
+       """ Rename a scheduled task """
+
+       if taskname and self.tasks.has_key(taskname):
+           task = self.tasks[taskname]
+           del self.tasks[taskname]
+           self.tasks[newname] = task
+
     if sys.version_info >= (2,6):
         # code for sched module of python 2.6+
         def _getqueuetoptime(self):
